"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.TaskProcessorCommand = void 0;
/**
 * Class to process external tasks configured as service
 * tasks in bpmn engine such as camunda.
 */
class TaskProcessorCommand {
    /**
     *
     * @param {Function} callbackFn plug in the logic given by the consumer
     * @param {Function} processFn process function to run after the logic is executed
     * @param {AnyObject[]} processParams an array of params required by the process function
     */
    constructor(callbackFn, processFn, processParams) {
        this.callbackFn = callbackFn;
        this.processFn = processFn;
        this.processParams = processParams;
    }
    /**
     * @property {Function} execute the logic within the external tasks
     * which are currently configured as service tasks
     * @return {void}
     */
    async execute() {
        const { task, taskService } = this.parameters;
        const { payload, vars } = this.callbackFn(task, taskService);
        await taskService.complete(task, vars);
        this.processParams.push(payload);
        await this.processFn(...this.processParams);
    }
}
exports.TaskProcessorCommand = TaskProcessorCommand;
//# sourceMappingURL=task-processor.command.js.map