"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.EventQueueServiceSQS = void 0;
const tslib_1 = require("tslib");
const context_1 = require("@loopback/context");
const core_1 = require("@loopback/core");
const rest_1 = require("@loopback/rest");
const keys_1 = require("../keys");
const event_processor_service_1 = require("./event-processor.service");
let EventQueueServiceSQS = class EventQueueServiceSQS {
    constructor(eventProcessorService, settings, connector) {
        this.eventProcessorService = eventProcessorService;
        this.settings = settings;
        this.connector = connector;
        this.listenForEvents();
    }
    async enqueueEvent(event) {
        const connection = await this.connector.connect(this.connector.settings);
        const params = {
            MessageBody: JSON.stringify(event),
            QueueUrl: this.settings.queueUrl,
        };
        await connection.sendMessage(params, (err, data) => {
            if (err) {
                throw new rest_1.HttpErrors.InternalServerError(`Error sending message: ${err.message}`);
            }
        });
    }
    listenForEvents() {
        // Start listening to the queue for incoming events
        const queueUrl = this.connector.settings.queueUrl;
        const receiveParams = {
            QueueUrl: queueUrl,
            MaxNumberOfMessages: 10,
            WaitTimeSeconds: 20,
        };
        const receiveMessages = async () => {
            const connection = await this.connector.connect(this.connector.settings);
            try {
                const data = await connection.receiveMessage(receiveParams).promise();
                const messages = data.Messages;
                if (messages === null || messages === void 0 ? void 0 : messages.length) {
                    const messagePromises = messages.map((message) => this._processEvent(message, connection, queueUrl));
                    await Promise.all(messagePromises);
                }
            }
            catch (error) {
                throw new rest_1.HttpErrors.InternalServerError(`Error with Queue, ${error}`);
            }
            /* eslint-disable */
            // Call the function recursively to continuously listen for new messages
            receiveMessages();
        };
        /* eslint-disable */
        // Start listening for events
        receiveMessages();
    }
    async healthCheck() {
        const healthCheckResponse = await this.connector.ping();
        return healthCheckResponse;
    }
    async _processEvent(message, connection, queueUrl) {
        const event = JSON.parse(message.Body || '{}');
        // Logic to process this event
        await this.eventProcessorService.processEvent(event);
        // Delete the processed message from the queue
        await connection
            .deleteMessage({
            QueueUrl: queueUrl,
            ReceiptHandle: message.ReceiptHandle,
        })
            .promise();
    }
};
exports.EventQueueServiceSQS = EventQueueServiceSQS;
exports.EventQueueServiceSQS = EventQueueServiceSQS = tslib_1.__decorate([
    (0, context_1.injectable)({
        scope: context_1.BindingScope.SINGLETON,
    }, core_1.asLifeCycleObserver),
    tslib_1.__param(0, (0, core_1.service)(event_processor_service_1.EventProcessorService)),
    tslib_1.__param(1, (0, context_1.inject)(keys_1.TaskServiceBindings.CONNECTOR_CONFIG)),
    tslib_1.__param(2, (0, context_1.inject)(keys_1.TaskServiceBindings.TASK_PROVIDER)),
    tslib_1.__metadata("design:paramtypes", [event_processor_service_1.EventProcessorService, Object, Object])
], EventQueueServiceSQS);
//# sourceMappingURL=event-queue.service.js.map