"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.UtilityService = void 0;
const tslib_1 = require("tslib");
const context_1 = require("@loopback/context");
const bpmn_service_1 = require("@sourceloop/bpmn-service");
const uuid_1 = require("uuid");
let UtilityService = class UtilityService {
    constructor(workerMapGetter) {
        this.workerMapGetter = workerMapGetter;
    }
    transformObject(obj) {
        const transformed = {};
        for (const key in obj) {
            if (obj.hasOwnProperty(key)) {
                transformed[key] = { value: obj[key] };
            }
        }
        return transformed;
    }
    async iterateWorkerMap(workflowName, callback) {
        const workerMap = await this.workerMapGetter();
        if (workerMap === null || workerMap === void 0 ? void 0 : workerMap[workflowName]) {
            for (const worker of workerMap[workflowName]) {
                const result = await callback(worker);
                if (result) {
                    return true;
                }
            }
        }
        return false;
    }
    generateApiKeyAndSecret(clientApp) {
        const apiKey = `${clientApp.key}-${(0, uuid_1.v4)()}`;
        const apiSecret = `${clientApp.secret}-${(0, uuid_1.v4)()}`;
        return { apiKey, apiSecret };
    }
};
exports.UtilityService = UtilityService;
exports.UtilityService = UtilityService = tslib_1.__decorate([
    (0, context_1.injectable)({ scope: context_1.BindingScope.TRANSIENT }),
    tslib_1.__param(0, context_1.inject.getter(bpmn_service_1.WorkflowServiceBindings.WORKER_MAP)),
    tslib_1.__metadata("design:paramtypes", [Function])
], UtilityService);
//# sourceMappingURL=utility.service.js.map