"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.WebhookService = void 0;
const tslib_1 = require("tslib");
const core_1 = require("@loopback/core");
const repository_1 = require("@loopback/repository");
const rest_1 = require("@loopback/rest");
const repositories_1 = require("../repositories");
const http_service_1 = require("./http.service");
let WebhookService = class WebhookService {
    constructor(webhookSubscriptionsRepo, httpService) {
        this.webhookSubscriptionsRepo = webhookSubscriptionsRepo;
        this.httpService = httpService;
    }
    async addToSubscription(url, key) {
        try {
            const webhookSubscriptions = await this.webhookSubscriptionsRepo.find({
                where: {
                    url,
                    key,
                },
            });
            if (webhookSubscriptions.length === 0) {
                await this.webhookSubscriptionsRepo.create({
                    key,
                    url,
                });
            }
        }
        catch (error) {
            throw new rest_1.HttpErrors.InternalServerError('Could not add to subscription');
        }
    }
    async getUrlOfSubscritption(key) {
        const webhookSubscriptions = await this.webhookSubscriptionsRepo.find({
            where: {
                key,
            },
        });
        if (webhookSubscriptions.length === 1) {
            return webhookSubscriptions[0].url;
        }
        return null;
    }
    async triggerWebhook(key, data) {
        try {
            const subscribers = await this.webhookSubscriptionsRepo.find({
                where: { key },
            });
            if (subscribers.length > 0) {
                const postPromises = subscribers.map(subscriber => this.httpService.post(subscriber.url, data));
                await Promise.all(postPromises);
            }
        }
        catch (error) {
            throw new rest_1.HttpErrors.InternalServerError('could not trigger webhook');
        }
    }
};
exports.WebhookService = WebhookService;
exports.WebhookService = WebhookService = tslib_1.__decorate([
    (0, core_1.injectable)({ scope: core_1.BindingScope.TRANSIENT }),
    tslib_1.__param(0, (0, repository_1.repository)(repositories_1.WebhookSubscriptionsRepository)),
    tslib_1.__param(1, (0, core_1.service)(http_service_1.HttpClientService)),
    tslib_1.__metadata("design:paramtypes", [repositories_1.WebhookSubscriptionsRepository,
        http_service_1.HttpClientService])
], WebhookService);
//# sourceMappingURL=webhook.service.js.map