import { AnyObject } from '@loopback/repository';
export declare const AuthDbSourceName = "AuthDB";
export declare const AuthCacheSourceName = "AuthCache";
export interface EventQueueConnector {
    name: string;
    settings: {
        [key: string]: AnyObject;
    };
    connect(settings: {
        [key: string]: AnyObject;
    }): Promise<AnyObject>;
    disconnect(settings: {
        [key: string]: AnyObject;
    }): Promise<void>;
    ping(): Promise<HealthResponse>;
}
export interface HealthResponse {
    greeting: string;
    date: string;
    url: string;
    headers: {
        [key: string]: string;
    };
}
export declare enum TaskServiceNames {
    EVENT = "event",
    TASK = "task",
    UPDATE = "update",
    CHECK = "check"
}
export interface EventPayload {
    workflowId: string;
    command: string;
    commandParams: AnyObject;
}
export interface Workflow {
    key: WorkflowKey;
    name: string;
    description: string;
    provider: string;
    inputSchema: AnyObject;
}
export interface EventWorkflowMapping {
    eventKey: EventKey;
    workflowKey: WorkflowKey;
    config: AnyObject;
}
export interface Task {
    id?: string;
    key: TaskKey;
    name: string;
    description?: string;
    status: TaskStatus;
    priority: TaskPriority;
    severity: TaskSeverity;
    type: TaskType;
    startDate?: Date;
    dueDate?: Date;
    endDate?: Date;
    assigneeId: string;
}
export interface Message {
    message: string;
    key: string;
    payload?: AnyObject;
    eventKey: EventKey;
    taskKey: TaskKey;
}
export type TaskReturnMap = {
    workerFunctions: Record<string, ProccessorFunction>;
    tasksArray: Task[];
};
export type ProccessorFunction = (task: AnyObject, taskService: AnyObject, payload: AnyObject) => {
    payload: AnyObject;
    vars: AnyObject | null;
};
export declare enum EventKey {
}
export declare enum EventSource {
}
export declare enum TaskKey {
    sample_key = "sample"
}
export declare enum WorkflowKey {
}
export declare enum TaskStatus {
    pending = "pending",
    in_progress = "in progress",
    completed = "completed"
}
export declare enum TaskPriority {
    high = "high"
}
export declare enum TaskSeverity {
    high = "high"
}
export declare enum TaskType {
    user = "user",
    workflow = "workflow"
}
export declare const TaskDbSourceName = "taskdb";
export declare const WorkflowServiceSourceName = "WorkflowCache";
export declare const ExportedWorkflowServiceBindingConfig: import("@loopback/context").BindingKey<import("@sourceloop/bpmn-service").IWorkflowServiceConfig | null>;
